==> sale-3.1.7-16.jar: revenue/sqls/MeterCharge/getOverdueWx.sql <==
      SELECT
        f_relation_sign,
        handplan_id,                                            --抄表记录id
        f_last_tablebase,                                        --上期指数
        f_tablebase,                                            --本期指数
        f_hand_date,                                            --抄表日期
        f_input_date,
        f_user_id,
        f_userinfo_code,
        f_user_name,
        f_address,
        f_userfiles_id,
        f_surplus_gas,
        f_haircut_gas,
        f_oughtamount,    --应交气量  convert(decimal(18,2),f_oughtamount)  ROUND(f_oughtamount,2)
        f_loss_gas,        --输损量 convert(decimal(18,2),f_loss_gas) ROUND(f_loss_gas,2)
        f_share_gas,        --承担量 convert(decimal(18,2),f_share_gas) ROUND(f_share_gas,2)
        ROUND(f_oughtfee-f_debt_money,2) f_oughtfee,            --实际应交金额 convert(decimal(18,2),f_oughtfee-f_debt_money) ROUND(f_oughtfee-f_debt_money,2)
        f_debt_money,    --已交气费 convert(decimal(18,2),f_debt_money) ROUND(f_debt_money,2)
        f_charge_money, --已交总金额 convert(decimal(18,2),f_charge_money) ROUND(f_charge_money,2)
        f_selloverdue,  --已交滞纳金 convert(decimal(18,2),f_selloverdue) ROUND(f_selloverdue,2)
        f_allfee,            --总应交金额 convert(decimal(18,2),f_oughtfee) ROUND(f_oughtfee,2)
        f_totalowe_gas, -- convert(decimal(18,2),f_totalowe_gas) ROUND(f_totalowe_gas,2)
        f_totalowe_fee, -- convert(decimal(18,2),f_totalowe_fee) ROUND(f_totalowe_fee,2)
        f_whether_pay,                                            --是否缴费
        f_end_date,                                            --截止日期
        CASE WHEN overduedays<1 THEN 0 ELSE overduedays END overduedays,    --滞纳天数
        f_balance,    --余额
        f_remission_late_fee, -- 滞纳金减免金额
      --滞纳天数小于0，不计算滞纳金，返回0
      convert(decimal(18,2),
        CASE WHEN overduedays<=0 THEN
              isnull(f_latefee_ought,0)
        ELSE
            --滞纳金天数大于0，若应交金额小于0
            CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end))<=0
            THEN
              isnull(f_latefee_ought,0)
            ELSE
              --判断应交金额是否小于0
              (CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -case when mh.minid is null   then 0 else f_balances end)+isnull(zhengchang,0)>=f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)
               THEN
                 CASE WHEN f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)<0 
                 THEN 0
                 ELSE 
					case when f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)-isnull(jianmian,0)<=0
						then 0 
						else f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)-isnull(jianmian,0)
					end
                 END
               ELSE
				 overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end))+isnull(f_latefee_ought,0)
               END)
            END
        END) overdue,
        --滞纳天数小于0，不计算滞纳金，返回0
        convert(decimal(18,2),
                CASE WHEN overduedays<=0 THEN
                       0
                     ELSE
                       --滞纳金天数大于0，若应交金额小于0
                       CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null then 0 else f_balances end ))<0
                              THEN
                              0
                            ELSE
                              --判断应交金额是否小于0
                              (CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end))
>=f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)
                                      THEN
                                      CASE WHEN f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)<0
                                             THEN 0
                                           ELSE f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)
                                        END
                                    ELSE
                                          overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end))
                                END)
                         END
                  END) f_overdue,
        isnull(f_latefee_ought,0) f_latefee_ought,
        splitNum,
        gh.minid,
        case when f_garbage_fee = '是' and f_input_date >= '2017-08-01' then
          (case when handplan_id = gh.minid or gh.minid is null then f_lajifei else 0 end)
        else 0 end
        f_garbage_fee
      FROM(
        SELECT
          id as handplan_id,
          f_relation_sign,
          f_last_tablebase,
          f_tablebase,
          h.f_hand_date,
          h.f_input_date,
          f_oughtamount,
          f_oughtfee,
          isnull(f_debt_money,0) f_debt_money,
          isnull(f_charge_money,0) f_charge_money,
          isnull(f_selloverdue,0) f_selloverdue,
          f_oughtfee f_allfee,
          f_whether_pay,
          f_loss_gas,
         isnull(f_remission_late_fee,0) f_remission_late_fee,
          h.f_end_date,
          h.f_user_id,
          h.f_userinfo_code,
          h.f_user_name,
          h.f_address,
          h.f_userfiles_id,
          f_surplus_gas,
          f_haircut_gas,
          f_share_gas,
          f_totalowe_fee,
          f_totalowe_gas,
          h.f_overdue,
          h.f_userinfo_id,
          lr.f_latefee_ought,
		  lr.jianmian,
		  lr.zhengchang,
          u.f_balance,
          case when u.f_balance<0 then 0 else u.f_balance end f_balances,
          uf.f_garbage_fee,
          --NVL(f_debt_money,0) f_debt_money,
          --isnull(f_charge_money,0) f_charge_money,
          --isnull(f_selloverdue,0)  f_selloverdue,
           --floor(sysdate - h.f_end_date) overduedays, --滞纳天数 oracle
          DATEDIFF(dd,f_end_date,getdate()) overduedays, --滞纳天数 sql server
          CASE WHEN h.f_user_type='民用'
          THEN isnull((SELECT cast(value as float) FROM  t_singlevalue WHERE name='民用违约金' and f_filialeids=u.f_orgid),(SELECT cast(value as float) FROM  t_singlevalue WHERE name='民用违约金'))
          ELSE
            isnull((SELECT cast(value as float) FROM  t_singlevalue WHERE name='非民用违约金' and f_filialeids=u.f_orgid),(SELECT cast(value as float) FROM  t_singlevalue WHERE name='非民用违约金'))
          END zhinajinbilv,
          (SELECT cast(value as int) FROM  t_singlevalue WHERE name='垃圾费') f_lajifei
        FROM t_handplan h
        LEFT JOIN (
          SELECT
            f_hand_id,SUM(f_debt_money) f_debt_money,
            SUM(f_charge_money) f_charge_money,SUM(f_overdue) f_selloverdue
          FROM t_sellinghand
          WHERE f_state = '有效'
          GROUP BY f_hand_id
        ) sh on h.id = sh.f_hand_id
        left join (
			 select f_hand_id,sum(f_latefee_ought) f_latefee_ought,sum(jianmian) jianmian,sum(zhengchang) zhengchang
									  from (
											 select f_hand_id,
													f_latefee_ought,
													case when f_latefee_ought<0 then 0-f_latefee_ought else 0 end jianmian,
													case when f_latefee_ought>0 then f_latefee_ought else 0 end zhengchang
											 from t_latefee_record where f_state='有效'
										   ) l group by f_hand_id
        ) lr on h.id = lr.f_hand_id
        LEFT JOIN t_userinfo u
            ON h.f_userinfo_id = u.f_userinfo_id
        left join t_userfiles uf on h.f_userfiles_id = uf.f_userfiles_id
        WHERE
          h.f_user_id = '{f_user_id}' and
          f_whether_pay='否' AND f_hand_state = '有效' and
          h.f_meter_state = '已抄表' AND f_oughtfee!=0
      ) p LEFT JOIN(
        SELECT f_meter_id,count(*) AS splitNum
        FROM t_userfiles
        WHERE f_meter_id = '{f_user_id}'
        GROUP BY f_meter_id
      ) s ON p.f_userfiles_id = s.f_meter_id
      left join(
        select CONVERT(varchar(7), f_hand_date, 23) f_date,min(id) minid
        from t_handplan
            where f_user_id = '{f_user_id}' AND f_hand_state = '有效' and f_meter_state = '已抄表' AND f_oughtfee>0
        group by CONVERT(varchar(7), f_hand_date, 23)
      ) gh on CONVERT(varchar(7), p.f_hand_date, 23) = gh.f_date
      left join (
		select min(id) minid
		from t_handplan
			where f_user_id = '{f_user_id}' AND f_hand_state = '有效' and f_meter_state = '已抄表'
			AND f_oughtfee>0 and f_whether_pay='否'
	  ) mh on p.handplan_id = mh.minid
      order by p.f_hand_date

==> sale-3.2.0.jar: revenue/sqls/MeterCharge/getOverdueWx.sql <==
      SELECT
        f_relation_sign,
        handplan_id,                                            --抄表记录id
        f_last_tablebase,                                        --上期指数
        f_tablebase,                                            --本期指数
        f_hand_date,                                            --抄表日期
        f_input_date,
        f_user_id,
        f_userinfo_code,
        f_user_name,
        f_address,
        f_userfiles_id,
        f_surplus_gas,
        f_haircut_gas,
        f_oughtamount,    --应交气量  convert(decimal(18,2),f_oughtamount)  ROUND(f_oughtamount,2)
        f_loss_gas,        --输损量 convert(decimal(18,2),f_loss_gas) ROUND(f_loss_gas,2)
        f_share_gas,        --承担量 convert(decimal(18,2),f_share_gas) ROUND(f_share_gas,2)
        ROUND(f_oughtfee-f_debt_money,2) f_oughtfee,            --实际应交金额 convert(decimal(18,2),f_oughtfee-f_debt_money) ROUND(f_oughtfee-f_debt_money,2)
        f_debt_money,    --已交气费 convert(decimal(18,2),f_debt_money) ROUND(f_debt_money,2)
        f_charge_money, --已交总金额 convert(decimal(18,2),f_charge_money) ROUND(f_charge_money,2)
        f_selloverdue,  --已交滞纳金 convert(decimal(18,2),f_selloverdue) ROUND(f_selloverdue,2)
        f_allfee,            --总应交金额 convert(decimal(18,2),f_oughtfee) ROUND(f_oughtfee,2)
        f_totalowe_gas, -- convert(decimal(18,2),f_totalowe_gas) ROUND(f_totalowe_gas,2)
        f_totalowe_fee, -- convert(decimal(18,2),f_totalowe_fee) ROUND(f_totalowe_fee,2)
        f_whether_pay,                                            --是否缴费
        f_end_date,                                            --截止日期
        case when f_start_date is null then
            CASE WHEN overduedays<1 THEN 0 ELSE overduedays END
        else DATEDIFF(dd,f_start_date,getdate()) end overduedays,    --滞纳天数
        f_balance,    --余额
        f_remission_late_fee, -- 滞纳金减免金额
      --滞纳天数小于0，不计算滞纳金，返回0
      convert(decimal(18,2),
        CASE WHEN overduedays<=0 THEN
              {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(f_latefee_ought,0)
        ELSE
            --滞纳金天数大于0，若应交金额小于0
            CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end))<=0
            THEN
              {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(f_latefee_ought,0)
            ELSE
              --判断应交金额是否小于0
              (CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -case when mh.minid is null   then 0 else f_balances end)+{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(zhengchang,0)>=f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)
               THEN
                 CASE WHEN f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)<0
                 THEN 0
                 ELSE
					case when f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)-{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(jianmian,0)<=0
						then 0
						else f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)-{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(jianmian,0)
					end
                 END
               ELSE
				 overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end))+{entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(f_latefee_ought,0)
               END)
            END
        END) overdue,
        --滞纳天数小于0，不计算滞纳金，返回0
        convert(decimal(18,2),
                CASE WHEN overduedays<=0 THEN
                       0
                     ELSE
                       --滞纳金天数大于0，若应交金额小于0
                       CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null then 0 else f_balances end ))<0
                              THEN
                              0
                            ELSE
                              --判断应交金额是否小于0
                              (CASE WHEN overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end))
>=f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)
                                      THEN
                                      CASE WHEN f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)<0
                                             THEN 0
                                           ELSE f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end)
                                        END
                                    ELSE
                                          overduedays*zhinajinbilv*(f_oughtfee-f_debt_money -(case when mh.minid is null  then 0 else f_balances end))
                                END)
                         END
                  END) f_overdue,
        {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(f_latefee_ought,0) f_latefee_ought,
        splitNum,
        gh.minid,
        case when f_garbage_fee = '是' and f_input_date >= '2017-08-01' then
          (case when handplan_id = gh.minid or gh.minid is null then f_lajifei else 0 end)
        else 0 end
        f_garbage_fee
      FROM(
        SELECT
          id as handplan_id,
          f_relation_sign,
          f_last_tablebase,
          f_tablebase,
          h.f_hand_date,
          h.f_input_date,
          f_oughtamount,
          f_oughtfee,
          {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(f_debt_money,0) f_debt_money,
          {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(f_charge_money,0) f_charge_money,
          {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(f_selloverdue,0) f_selloverdue,
          f_oughtfee f_allfee,
          f_whether_pay,
          f_loss_gas,
         {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}(f_remission_late_fee,0) f_remission_late_fee,
          h.f_end_date,
          h.f_user_id,
          h.f_userinfo_code,
          h.f_user_name,
          h.f_address,
          h.f_userfiles_id,
          f_surplus_gas,
          f_haircut_gas,
          f_share_gas,
          f_totalowe_fee,
          f_totalowe_gas,
          h.f_overdue,
          h.f_userinfo_id,
          lr.f_latefee_ought,
		  lr.jianmian,
		  lr.zhengchang,
          u.f_balance,
          case when u.f_balance<0 then 0 else u.f_balance end f_balances,
          uf.f_garbage_fee,
          --NVL(f_debt_money,0) f_debt_money,
          --isnull(f_charge_money,0) f_charge_money,
          --isnull(f_selloverdue,0)  f_selloverdue,
           --floor(sysdate - h.f_end_date) overduedays, --滞纳天数 oracle
           f_start_date,
          DATEDIFF(dd,f_end_date,getdate()) overduedays, --滞纳天数 sql server
          CASE WHEN h.f_user_type='民用'
          THEN {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}((SELECT cast(value as float) FROM  t_singlevalue WHERE name='民用违约金' and f_filialeids=u.f_orgid),(SELECT cast(value as float) FROM  t_singlevalue WHERE name='民用违约金'))
          ELSE
            {entity.findDialect()==$SqlServer$: $isnull$,$NVL$}((SELECT cast(value as float) FROM  t_singlevalue WHERE name='非民用违约金' and f_filialeids=u.f_orgid),(SELECT cast(value as float) FROM  t_singlevalue WHERE name='非民用违约金'))
          END zhinajinbilv,
          (SELECT cast(value as int) FROM  t_singlevalue WHERE name='垃圾费') f_lajifei
        FROM t_handplan h
        LEFT JOIN (
          SELECT
            f_hand_id,SUM(f_debt_money) f_debt_money,
            SUM(f_charge_money) f_charge_money,SUM(f_overdue) f_selloverdue
          FROM t_sellinghand
          WHERE f_state = '有效'
          GROUP BY f_hand_id
        ) sh on h.id = sh.f_hand_id
        left join (
			 select f_hand_id,min(f_start_date) f_start_date,sum(f_latefee_ought) f_latefee_ought,sum(jianmian) jianmian,sum(zhengchang) zhengchang
									  from (
											 select f_hand_id,
											        f_start_date,
													f_latefee_ought,
													case when f_latefee_ought<0 then 0-f_latefee_ought else 0 end jianmian,
													case when f_latefee_ought>0 then f_latefee_ought else 0 end zhengchang
											 from t_latefee_record where f_state='有效'
										   ) l group by f_hand_id
        ) lr on h.id = lr.f_hand_id
        LEFT JOIN t_userinfo u
            ON h.f_userinfo_id = u.f_userinfo_id
        left join t_userfiles uf on h.f_userfiles_id = uf.f_userfiles_id
        WHERE
          h.f_user_id = '{f_user_id}' and
          f_whether_pay='否' AND f_hand_state = '有效' and
          h.f_meter_state = '已抄表' AND f_oughtfee!=0
      ) p LEFT JOIN(
        SELECT f_meter_id,count(*) AS splitNum
        FROM t_userfiles
        WHERE f_meter_id = '{f_user_id}'
        GROUP BY f_meter_id
      ) s ON p.f_userfiles_id = s.f_meter_id
      left join(
        select CONVERT(varchar(7), f_hand_date, 23) f_date,min(id) minid
        from t_handplan
            where f_user_id = '{f_user_id}' AND f_hand_state = '有效' and f_meter_state = '已抄表' AND f_oughtfee>0
        group by CONVERT(varchar(7), f_hand_date, 23)
      ) gh on CONVERT(varchar(7), p.f_hand_date, 23) = gh.f_date
      left join (
		select min(id) minid
		from t_handplan
			where f_user_id = '{f_user_id}' AND f_hand_state = '有效' and f_meter_state = '已抄表'
			AND f_oughtfee>0 and f_whether_pay='否'
	  ) mh on p.handplan_id = mh.minid
      order by p.f_hand_date
